import random


def getRandomNumSet(bits):
    ''' 随机生成定长的小写字母和数字组合'''
    num_set = [chr(i) for i in range(48, 58)]
    total_set = num_set

    value_set = "".join(random.sample(total_set, bits))
    return value_set





import uuid

from .models import DistributeAfsplus


def get_distribute_afsplus_infos(dis_ids):
    ''' 根据发货单ID查询在途 DistributeAfsplus '''
    objs = DistributeAfsplus.objects.filter(distribute_id__in=dis_ids, if_need_afsplus=True)

    results = [
        {
            'distribute_id': obj.distribute_id,
            'if_need_afsplus': obj.if_need_afsplus,
            'afsplus_type_show': obj.afsplus_type_show,
            'if_done_afsplus': obj.if_done_afsplus,
        } for obj in objs
    ]
    return results


